``hist()`` supports a single color for multiple datasets
--------------------------------------------------------

It is now possible to pass a single *color* value to `~.Axes.hist()`. This
value is applied to all datasets.
